@@ -2,11 +2,11 @@
 #######################################################################
 """RemoteObjectEdit MixIn for the Zope 3 based ng.app.remotefs package
 
-$Id: quotareindex.py 49750 2008-01-27 19:51:18Z cray $
+$Id: quotareindex.py 49752 2008-01-27 20:25:18Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49750 $"
+__version__ = "$Revision: 49752 $"
 
 import sys
 from ng.lib.walk import BFSWalkTree
@@ -14,6 +14,8 @@ from ng.app.quota.interfaces import IQuota, IQuotaAnnotation
 from histogram import Histogram
 from zope.component import getUtilitiesFor
 from zope.app.intid.interfaces import IIntIds
+from zope.traversing.interfaces import IPhysicallyLocatable
+
 
 class QuotaReindex(Histogram) :
 
@@ -25,13 +27,15 @@ class QuotaReindex(Histogram) :
             try :
                 quota = IQuotaAnnotation(self.context)
                 quota.reset()
+                stat = quota.stat
+                quota.stat = True
                 if IQuotaAnnotation.providedBy(self.context) :
-                    for name,intids in getUtilitiesFor(IIntIds,context=self.context) :
-                        for key in intids :
-                            quota.handleAdded(intids.queryObject(key))
+                    root = IPhysicallyLocatable(self.context).getNearestSite()
                 else :
-                    for ob in BFSWalkTree(self.context) :
-                        quota.handleAdded(ob)
+                    root = self.context
+                for ob in BFSWalkTree(root) :
+                    quota.handleAdded(ob)
+                quota.stat = stat                    
             except Exception, msg :
                 self.msg = msg                
                 print sys.excepthook(*sys.exc_info())
@@ -40,3 +44,6 @@ class QuotaReindex(Histogram) :
         
         
         
+                #    for name,intids in getUtilitiesFor(IIntIds,context=self.context) :
+                #        for key in intids :
+                #            quota.handleAdded(intids.queryObject(key))
